@@ -5,20 +5,20 @@ import (
 	"testing"
 	"time"
 
-	"github.com/cloudskiff/driftctl/pkg/remote/cache"
 	"github.com/sirupsen/logrus"
+	"github.com/snyk/driftctl/pkg/remote/cache"
 
-	"github.com/cloudskiff/driftctl/pkg/remote/aws/repository"
-	"github.com/cloudskiff/driftctl/test"
+	"github.com/snyk/driftctl/pkg/remote/aws/repository"
+	"github.com/snyk/driftctl/test"
 
 	"github.com/aws/aws-sdk-go/service/sns"
 
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/cloudskiff/driftctl/pkg/analyser"
-	awsresources "github.com/cloudskiff/driftctl/pkg/resource/aws"
-	"github.com/cloudskiff/driftctl/test/acceptance"
-	"github.com/cloudskiff/driftctl/test/acceptance/awsutils"
 	"github.com/r3labs/diff/v2"
+	"github.com/snyk/driftctl/pkg/analyser"
+	awsresources "github.com/snyk/driftctl/pkg/resource/aws"
+	"github.com/snyk/driftctl/test/acceptance"
+	"github.com/snyk/driftctl/test/acceptance/awsutils"
 )
 
 func TestAcc_AwsSNSTopic(t *testing.T) {
